(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     23632,        632]
NotebookOptionsPosition[     21401,        590]
NotebookOutlinePosition[     21809,        606]
CellTagsIndexPosition[     21766,        603]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Horizontal Deflection of a Falling Object", "Title",
 CellChangeTimes->{{3.8602473053744926`*^9, 3.860247330681143*^9}, {
  3.8602490740835123`*^9, 
  3.8602490920471582`*^9}},ExpressionUUID->"950bc84c-c9c1-432f-8e47-\
64d415e2a4fb"],

Cell["Marvin Zanke & Leon von Detten", "Author",
 CellChangeTimes->{{3.860247336370386*^9, 
  3.860247347914021*^9}},ExpressionUUID->"191f3590-0475-45be-8996-\
7a8eaf5486d0"],

Cell["29.04.2022", "Date",
 CellChangeTimes->{{3.8602473498244123`*^9, 
  3.86024735665908*^9}},ExpressionUUID->"859d0fdc-947f-40b3-974c-\
feba7368ffd0"],

Cell[TextData[{
 "In this notebook, we solve the coupled differential equations obtained in \
H1a) of exercise sheet 4. For an ease of notation, we use unprimed \
coordinates, x(t)=x\[CloseCurlyQuote](t), y(t)=y\[CloseCurlyQuote](t), and \
z(t)=z\[CloseCurlyQuote](t). The system of coupled differential equations \
then reads\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\n", 
    RowBox[{
     RowBox[{
      RowBox[{
       OverscriptBox["x", "\[DoubleDot]"], "(", "t", ")"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"Sin", "(", "\[Phi]", ")"}], " ", 
        RowBox[{
         OverscriptBox["y", "."], "(", "t", ")"}]}], " ", "+", " ", 
       RowBox[{"O", "(", 
        SuperscriptBox["\[Omega]", "2"], ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       OverscriptBox["y", "\[DoubleDot]"], "(", "t", ")"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"\[Omega]", " ", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "(", "\[Phi]", ")"}], " ", 
           RowBox[{
            OverscriptBox["x", "."], "(", "t", ")"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"Cos", "(", "\[Phi]", ")"}], " ", 
           RowBox[{
            OverscriptBox["z", "."], "(", "t", ")"}]}]}], "]"}]}], " ", "+", 
       " ", 
       RowBox[{"O", "(", 
        SuperscriptBox["\[Omega]", "2"], ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       OverscriptBox["z", "\[DoubleDot]"], "(", "t", ")"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", "g"}], " ", "+", " ", 
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"Cos", "(", "\[Phi]", ")"}], " ", 
        RowBox[{
         OverscriptBox["y", "."], "(", "t", ")"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"O", "(", 
         SuperscriptBox["\[Omega]", "2"], ")"}], "."}]}]}]}]}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "21513e8f-55ca-4733-b7c4-cce64141d6e9"]
}], "Text",
 CellChangeTimes->{{3.86024736377672*^9, 3.860247418145917*^9}, {
  3.860247749933839*^9, 3.86024779087967*^9}, {3.860248370596568*^9, 
  3.860248675780637*^9}},ExpressionUUID->"b51484cd-7ee9-4b8a-af65-\
796eeb0ce0fc"],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.86024741974072*^9, 
  3.8602474254484653`*^9}},ExpressionUUID->"0774ed7b-2972-4d92-a9e8-\
281e66daeb7c"],

Cell["\<\
Define the (coupled) differential equations for x(t), y(t), and z(t).\
\>", "Text",
 CellChangeTimes->{{3.860247860368127*^9, 3.860247866215138*^9}, {
  3.860248714168743*^9, 
  3.860248715920054*^9}},ExpressionUUID->"21b1a21f-e3ec-46cf-b9d3-\
8c63b4ce30e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Note", " ", "that", " ", "derivatives", " ", "are", " ", "entered", " ", 
     "with", " ", "a", " ", "prime", " ", "in", " ", "Mathematica", " ", 
     "and", " ", "no", " ", "difference", " ", "is", " ", "made", " ", "for", 
     " ", "a", " ", "differentation", " ", "with", " ", "respect", " ", "to", 
     " ", "the", " ", "time", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "which", " ", "is", " ", "usually", " ", "denoted", " ", "by", " ", 
         "a", " ", "dot", " ", "in", " ", "physics"}], ",", " ", 
        RowBox[{"see", " ", "above"}]}], ")"}], ".", " ", "Furthermore"}]}], 
    ",", " ", 
    RowBox[{"we", " ", "omit", " ", "the", " ", "terms", " ", "O", 
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["\[Omega]", "2"], ")"}], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DiffEqx", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "''"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{"2", "\[Omega]", "*", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}], "*", 
       RowBox[{
        RowBox[{"y", "'"}], "[", "t", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DiffEqy", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "''"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", "2"}], "\[Omega]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", "\[Phi]", "]"}], "*", 
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], "*", 
          RowBox[{
           RowBox[{"z", "'"}], "[", "t", "]"}]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DiffEqz", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"z", "''"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", "g"}], "+", 
       RowBox[{"2", "\[Omega]", "*", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], "*", 
        RowBox[{
         RowBox[{"y", "'"}], "[", "t", "]"}]}]}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860247437287243*^9, 3.8602475625001383`*^9}, {
  3.860247833630628*^9, 3.8602479222241983`*^9}, {3.8602481111415777`*^9, 
  3.860248114067305*^9}, {3.860248477822034*^9, 3.860248494312674*^9}, {
  3.8602487014088917`*^9, 3.860248705505674*^9}, {3.86024878130713*^9, 
  3.8602487959641037`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"3f8eb91e-2fc9-449e-9f97-3332593414ce"],

Cell[TextData[{
 "Define the initial conditions for the velocity and position: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["v", "\[RightVector]"], "0"], "=", "0"}], ",", " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["r", "\[RightVector]"], "0"], "=", 
     RowBox[{"(", 
      RowBox[{"0", ",", "0", ",", "h"}], ")"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "95554ddb-d2a9-44a2-92bf-053666c93974"],
 "."
}], "Text",
 CellChangeTimes->{{3.860247924166102*^9, 3.860247932389195*^9}, {
  3.860247963857403*^9, 3.8602479681757298`*^9}, {3.8602487355676394`*^9, 
  3.860248763522595*^9}, {3.8602488115311337`*^9, 
  3.8602488117559147`*^9}},ExpressionUUID->"90bdcf63-76bc-4ebc-b9d7-\
71a6f805bd6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Initial", " ", "conditions", " ", "for", " ", "the", " ", 
    RowBox[{"velocity", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"InitCondvx", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InitCondvy", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InitCondvz", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"z", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Initial", " ", "conditions", " ", "for", " ", "the", " ", 
     RowBox[{"position", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InitCondx", "=", 
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], "\[Equal]", "0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InitCondy", "=", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", "0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InitCondz", "=", 
     RowBox[{
      RowBox[{"z", "[", "0", "]"}], "\[Equal]", "h"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860247933616974*^9, 3.860247955420204*^9}, {
  3.8602481171649714`*^9, 3.860248128385894*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"c062c9ff-0fa7-48b5-85f7-22b265bdeb26"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the System of Coupled Differential Equations", "Section",
 CellChangeTimes->{{3.8602479753945007`*^9, 3.8602479966724463`*^9}, {
  3.8602491224533863`*^9, 
  3.860249123599456*^9}},ExpressionUUID->"97dfc5ff-e2f2-4c7b-8c5f-\
52143e95fd07"],

Cell["\<\
Use the function \[OpenCurlyDoubleQuote]DSolve[...]\[CloseCurlyDoubleQuote] \
to solve the system of coupled differential equations. Select \
\[OpenCurlyDoubleQuote]DSolve[...]\[CloseCurlyDoubleQuote] and go to \
\[OpenCurlyDoubleQuote]Help \[Rule] Find Selected Function\
\[CloseCurlyDoubleQuote] to find more information on the syntax.\
\>", "Text",
 CellChangeTimes->{{3.860248842713893*^9, 
  3.860248915182787*^9}},ExpressionUUID->"fcddf130-4566-4afa-955e-\
1044fce1f8aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "that", " ", "the", " ", "solution", " ", "obtained", " ", 
    "here", " ", "does", " ", "not", " ", "yet", " ", "drop", " ", "terms", 
    " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["\[Omega]", "2"], ")"}], " ", "and", " ", "higher", " ", 
    RowBox[{"consistently", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"DiffEqSol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "DiffEqx", ",", "DiffEqy", ",", "DiffEqz", ",", "InitCondvx", ",", 
        "InitCondvy", ",", "InitCondvz", ",", "InitCondx", ",", "InitCondy", 
        ",", "InitCondz"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", 
        RowBox[{"y", "[", "t", "]"}], ",", 
        RowBox[{"z", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.860246753603807*^9, 3.8602467613605833`*^9}, {
   3.8602467947193413`*^9, 3.86024693161064*^9}, {3.860247126100976*^9, 
   3.860247174388391*^9}, 3.8602474366812973`*^9, {3.8602474677072067`*^9, 
   3.860247486549967*^9}, {3.860247517094232*^9, 3.86024753958468*^9}, {
   3.860247613037074*^9, 3.860247684861206*^9}, {3.860248013189273*^9, 
   3.860248026354568*^9}, {3.860248135927474*^9, 3.86024814716881*^9}, {
   3.860248833072019*^9, 3.860248835858477*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"a7f63c79-5882-4a25-9a87-d087f92b4849"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "(", "t", ")"}], "\[Rule]", 
      FractionBox[
       RowBox[{"g", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "t", " ", 
          "\[Omega]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["t", "2"], " ", 
              SuperscriptBox["\[Omega]", "2"]}], "-", "2"}], ")"}]}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], 
          "+", "1"}], ")"}], " ", 
        RowBox[{"sin", "(", "\[Phi]", ")"}], " ", 
        RowBox[{"cos", "(", "\[Phi]", ")"}]}], 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Omega]", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"y", "(", "t", ")"}], "\[Rule]", 
      FractionBox[
       RowBox[{"g", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "t", " ", "\[Omega]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "t", " ", 
             "\[Omega]"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]]}]}], 
         ")"}], " ", 
        RowBox[{"cos", "(", "\[Phi]", ")"}]}], 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Omega]", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"z", "(", "t", ")"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "t", " ", 
          "\[Omega]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"g", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                "2", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], " ", 
               
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["t", "2"], " ", 
                  SuperscriptBox["\[Omega]", "2"]}], "+", "1"}], ")"}]}]}], 
             "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]],
              "+", "1"}], ")"}]}], "+", 
          RowBox[{"g", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
               "2", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["t", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}], "-", "2"}], ")"}]}], "+", 
             
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]],
              "+", "1"}], ")"}], " ", 
           RowBox[{"cos", "(", 
            RowBox[{"2", " ", "\[Phi]"}], ")"}]}], "+", 
          RowBox[{"16", " ", "h", " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
            "2", " ", "\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]]}]}], 
         ")"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Omega]", "2"]}]]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.860246927358967*^9, 3.8602469346482477`*^9}, 
   3.860247175883168*^9, 3.860247653487764*^9, 3.860247724166506*^9, 
   3.860248152124979*^9, 3.8602482231706133`*^9, 3.860249029027834*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"97d08e3a-49df-480d-9b3e-287a0b771fa2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Store", " ", "the", " ", "solutions", " ", "for", " ", "x", 
     RowBox[{"(", "t", ")"}]}], ",", " ", 
    RowBox[{"y", 
     RowBox[{"(", "t", ")"}]}], ",", " ", 
    RowBox[{"and", " ", "z", 
     RowBox[{"(", "t", ")"}], " ", 
     RowBox[{"separately", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DiffEqSolx", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"DiffEqSol", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DiffEqSoly", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"DiffEqSol", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DiffEqSolz", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"DiffEqSol", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8602476745262203`*^9, 3.860247702837537*^9}, {
  3.860248031032518*^9, 3.860248045026327*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"6cc98c47-5bf5-4ccc-b398-621ba2fe8c1f"],

Cell[TextData[{
 "Perform a Taylor expansion around \[Omega]=0 and drop ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["\[Omega]", "2"], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "9b22d0b2-5675-49ea-9cb6-83f09205a6fd"],
 " and higher terms in the solution. Note that the solution in the tutorials \
was simplified by the fact that terms ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["\[Omega]", "2"], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "ebc6a9a8-203e-42dd-9fb2-e0a664d90d7d"],
 " and higher were dropped at an earlier stage, which, here, was only done in \
the differential equations themselves up to now and not throughout the \
calculation."
}], "Text",
 CellChangeTimes->{{3.8602481719480753`*^9, 3.860248189531045*^9}, {
  3.8602482550930758`*^9, 3.8602482906127167`*^9}, {3.860248943947152*^9, 
  3.8602490084823017`*^9}},ExpressionUUID->"594346c3-3598-4b32-b816-\
37bea9b81a0f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"For", " ", "x", 
    RowBox[{
     RowBox[{"(", "t", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"DiffEqSolx", ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"For", " ", "y", 
     RowBox[{
      RowBox[{"(", "t", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"DiffEqSoly", ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"For", " ", "z", 
     RowBox[{
      RowBox[{"(", "t", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"DiffEqSolz", ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.860247193393702*^9, 3.8602472062345753`*^9}, {
  3.860247243996806*^9, 3.86024727631324*^9}, {3.860247713594081*^9, 
  3.860247731796156*^9}, {3.860248051731764*^9, 3.860248079192552*^9}, {
  3.860248165261241*^9, 3.8602482075817003`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"70cad5a1-72e0-407a-98d8-043d8bd06811"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"O", "(", 
    SuperscriptBox["\[Omega]", "2"], ")"}],
   SeriesData[$CellContext`\[Omega], 0, {}, 2, 2, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.86024720694947*^9, {3.8602472473353043`*^9, 3.860247276643607*^9}, {
   3.860247728772512*^9, 3.860247736283538*^9}, 3.8602482233479023`*^9, 
   3.860249029279475*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"244af149-d3c3-4791-bde2-b9da81f27332"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", "g", " ", 
     SuperscriptBox["t", "3"], " ", "\[Omega]", " ", 
     RowBox[{"cos", "(", "\[Phi]", ")"}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["\[Omega]", "2"], ")"}],
     SeriesData[$CellContext`\[Omega], 0, {}, 1, 2, 1],
     Editable->False]}],
   SeriesData[$CellContext`\[Omega], 0, {
    Rational[1, 3] $CellContext`g $CellContext`t^3 Cos[$CellContext`\[Phi]]}, 
    1, 2, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.86024720694947*^9, {3.8602472473353043`*^9, 3.860247276643607*^9}, {
   3.860247728772512*^9, 3.860247736283538*^9}, 3.8602482233479023`*^9, 
   3.8602490292856007`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"05e7ef04-557b-4eeb-a376-aceebf9ae545"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"h", "-", 
      FractionBox[
       RowBox[{"g", " ", 
        SuperscriptBox["t", "2"]}], "2"]}], ")"}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["\[Omega]", "2"], ")"}],
     SeriesData[$CellContext`\[Omega], 0, {}, 0, 2, 1],
     Editable->False]}],
   SeriesData[$CellContext`\[Omega], 
    0, {$CellContext`h + Rational[-1, 2] $CellContext`g $CellContext`t^2}, 0, 
    2, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.86024720694947*^9, {3.8602472473353043`*^9, 3.860247276643607*^9}, {
   3.860247728772512*^9, 3.860247736283538*^9}, 3.8602482233479023`*^9, 
   3.860249029288583*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"f67fc459-50a1-4072-83f6-dd846be0b530"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 605},
WindowMargins->{{28, Automatic}, {36, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 239, 4, 97, "Title",ExpressionUUID->"950bc84c-c9c1-432f-8e47-64d415e2a4fb"],
Cell[822, 28, 174, 3, 40, "Author",ExpressionUUID->"191f3590-0475-45be-8996-7a8eaf5486d0"],
Cell[999, 33, 153, 3, 42, "Date",ExpressionUUID->"859d0fdc-947f-40b3-974c-feba7368ffd0"],
Cell[1155, 38, 2284, 60, 176, "Text",ExpressionUUID->"b51484cd-7ee9-4b8a-af65-796eeb0ce0fc"],
Cell[CellGroupData[{
Cell[3464, 102, 157, 3, 69, "Section",ExpressionUUID->"0774ed7b-2972-4d92-a9e8-281e66daeb7c"],
Cell[3624, 107, 268, 6, 34, "Text",ExpressionUUID->"21b1a21f-e3ec-46cf-b9d3-8c63b4ce30e1"],
Cell[3895, 115, 2557, 68, 170, "Input",ExpressionUUID->"3f8eb91e-2fc9-449e-9f97-3332593414ce"],
Cell[6455, 185, 789, 21, 34, "Text",ExpressionUUID->"90bdcf63-76bc-4ebc-b9d7-71a6f805bd6c"],
Cell[7247, 208, 1533, 43, 210, "Input",ExpressionUUID->"c062c9ff-0fa7-48b5-85f7-22b265bdeb26"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8817, 256, 250, 4, 69, "Section",ExpressionUUID->"97dfc5ff-e2f2-4c7b-8c5f-52143e95fd07"],
Cell[9070, 262, 487, 9, 57, "Text",ExpressionUUID->"fcddf130-4566-4afa-955e-1044fce1f8aa"],
Cell[CellGroupData[{
Cell[9582, 275, 1501, 32, 128, "Input",ExpressionUUID->"a7f63c79-5882-4a25-9a87-d087f92b4849"],
Cell[11086, 309, 4218, 109, 108, "Output",ExpressionUUID->"97d08e3a-49df-480d-9b3e-287a0b771fa2"]
}, Open  ]],
Cell[15319, 421, 1380, 38, 105, "Input",ExpressionUUID->"6cc98c47-5bf5-4ccc-b398-621ba2fe8c1f"],
Cell[16702, 461, 1008, 23, 107, "Text",ExpressionUUID->"594346c3-3598-4b32-b816-37bea9b81a0f"],
Cell[CellGroupData[{
Cell[17735, 488, 1460, 37, 189, "Input",ExpressionUUID->"70cad5a1-72e0-407a-98d8-043d8bd06811"],
Cell[19198, 527, 485, 11, 47, "Output",ExpressionUUID->"244af149-d3c3-4791-bde2-b9da81f27332"],
Cell[19686, 540, 849, 21, 57, "Output",ExpressionUUID->"05e7ef04-557b-4eeb-a376-aceebf9ae545"],
Cell[20538, 563, 823, 22, 63, "Output",ExpressionUUID->"f67fc459-50a1-4072-83f6-dd846be0b530"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

